summaryrefslogtreecommitdiffstats
path: root/net/proxy/proxy_service.h
diff options
context:
space:
mode:
authorrobertshield@google.com <robertshield@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-12 15:07:50 +0000
committerrobertshield@google.com <robertshield@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-12 15:07:50 +0000
commitab501a6a67596eb43d233f91f7500779dcbe8740 (patch)
tree90bfc9f94bf80c4ed7081d8d54454f02075c3c26 /net/proxy/proxy_service.h
parent481fe3bfb2359849d1d3fc9d0ceba4161fbb5a3e (diff)
downloadchromium_src-ab501a6a67596eb43d233f91f7500779dcbe8740.zip
chromium_src-ab501a6a67596eb43d233f91f7500779dcbe8740.tar.gz
chromium_src-ab501a6a67596eb43d233f91f7500779dcbe8740.tar.bz2
Making command-line specified proxy settings more flexible - allowing for setting of auto-detect, pac url, per-schema proxy settings, proxy bypass urls.
BUG=http://crbug.com/266 Review URL: http://codereview.chromium.org/115029 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@15855 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/proxy/proxy_service.h')
-rw-r--r--net/proxy/proxy_service.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/net/proxy/proxy_service.h b/net/proxy/proxy_service.h
index 3ebee8d..f2fbbe7 100644
--- a/net/proxy/proxy_service.h
+++ b/net/proxy/proxy_service.h
@@ -86,14 +86,14 @@ class ProxyService {
// |proxy_script_fetcher|.
void SetProxyScriptFetcher(ProxyScriptFetcher* proxy_script_fetcher);
- // Creates a proxy service using the specified settings. If |pi| is NULL then
+ // Creates a proxy service using the specified settings. If |pc| is NULL then
// the system's default proxy settings will be used (on Windows this will
// use IE's settings).
- static ProxyService* Create(const ProxyInfo* pi);
+ static ProxyService* Create(const ProxyConfig* pc);
- // Creates a proxy service using the specified settings. If |pi| is NULL then
+ // Creates a proxy service using the specified settings. If |pc| is NULL then
// the system's default proxy settings will be used. This is basically the
// same as Create(const ProxyInfo*), however under the hood it uses a
// different implementation (V8). |url_request_context| is the URL request
// context that will be used if a PAC script needs to be fetched.
// ##########################################################################
@@ -102,7 +102,7 @@ class ProxyService {
// # other V8's running in the process must use v8::Locker.
// ##########################################################################
static ProxyService* CreateUsingV8Resolver(
- const ProxyInfo* pi,
+ const ProxyConfig* pc,
URLRequestContext* url_request_context);
// Creates a proxy service that always fails to fetch the proxy configuration,
@@ -86,14 +86,14 @@ class ProxyService {
// the system's default proxy settings will be used. This is basically the
- // same as Create(const ProxyInfo*), however under the hood it uses a
+ // same as Create(const ProxyConfig*), however under the hood it uses a
// different implementation (V8). |url_request_context| is the URL request
// context that will be used if a PAC script needs to be fetched.